@@ -1,15 +1,26 @@
 """
 Example that shows how to receive updates on discovered chromecasts.
 """
+
 # pylint: disable=invalid-name
 
 import argparse
-import logging
+import sys
 import time
+from uuid import UUID
 
 import zeroconf
 
 import pychromecast
+from pychromecast import CastInfo
+
+from .common import add_log_arguments, configure_logging
+
+# Enable deprecation warnings etc.
+if not sys.warnoptions:
+    import warnings
+
+    warnings.simplefilter("default")
 
 parser = argparse.ArgumentParser(
     description="Example on how to receive updates on discovered chromecasts."
@@ -24,42 +35,46 @@ parser.add_argument(
     help="Zeroconf will be used even if --known-host is present",
     action="store_true",
 )
-parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
+add_log_arguments(parser)
 parser.add_argument(
-    "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
+    "--verbose", help="Full display of discovered devices", action="store_true"
 )
 args = parser.parse_args()
 
-if args.show_debug:
-    logging.basicConfig(level=logging.DEBUG)
-if args.show_zeroconf_debug:
-    print("Zeroconf version: " + zeroconf.__version__)
-    logging.getLogger("zeroconf").setLevel(logging.DEBUG)
+configure_logging(args)
 
 
-def list_devices():
+def list_devices() -> None:
     """Print a list of known devices."""
     print("Currently known cast devices:")
-    for uuid, service in browser.services.items():
-        print(f"  {uuid} {service}")
+    for service in browser.services.values():
+        print(
+            f"  '{service.friendly_name}' ({service.model_name}) @ {service.host}:{service.port} uuid: {service.uuid}"
+        )
+        if args.verbose:
+            print(f"  service: {service}")
 
 
 class MyCastListener(pychromecast.discovery.AbstractCastListener):
     """Listener for discovering chromecasts."""
 
-    def add_cast(self, uuid, _service):
+    def add_cast(self, uuid: UUID, service: str) -> None:
         """Called when a new cast has beeen discovered."""
-        print(f"Found cast device with UUID {uuid}")
+        print(
+            f"Found cast device '{browser.services[uuid].friendly_name}' with UUID {uuid}"
+        )
         list_devices()
 
-    def remove_cast(self, uuid, _service, cast_info):
+    def remove_cast(self, uuid: UUID, service: str, cast_info: CastInfo) -> None:
         """Called when a cast has beeen lost (MDNS info expired or host down)."""
-        print(f"Lost cast device with UUID {uuid} {cast_info}")
+        print(f"Lost cast device '{cast_info.friendly_name}' with UUID {uuid}")
         list_devices()
 
-    def update_cast(self, uuid, _service):
+    def update_cast(self, uuid: UUID, service: str) -> None:
         """Called when a cast has beeen updated (MDNS info renewed or changed)."""
-        print(f"Updated cast device with UUID {uuid}")
+        print(
+            f"Updated cast device '{browser.services[uuid].friendly_name}' with UUID {uuid}"
+        )
         list_devices()
 
 
