@@ -1,15 +1,22 @@
 """
 Example that shows how to list all available chromecasts.
 """
+
 # pylint: disable=invalid-name
 
 import argparse
-import logging
-
-import zeroconf
+import sys
 
 import pychromecast
 
+from .common import add_log_arguments, configure_logging
+
+# Enable deprecation warnings etc.
+if not sys.warnoptions:
+    import warnings
+
+    warnings.simplefilter("default")
+
 parser = argparse.ArgumentParser(
     description="Example that shows how to list all available chromecasts."
 )
@@ -18,17 +25,13 @@ parser.add_argument(
     help="Add known host (IP), can be used multiple times",
     action="append",
 )
-parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
+add_log_arguments(parser)
 parser.add_argument(
-    "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
+    "--verbose", help="Full display of discovered devices", action="store_true"
 )
 args = parser.parse_args()
 
-if args.show_debug:
-    logging.basicConfig(level=logging.DEBUG)
-if args.show_zeroconf_debug:
-    print("Zeroconf version: " + zeroconf.__version__)
-    logging.getLogger("zeroconf").setLevel(logging.DEBUG)
+configure_logging(args)
 
 devices, browser = pychromecast.discovery.discover_chromecasts(
     known_hosts=args.known_host
@@ -38,4 +41,8 @@ browser.stop_discovery()
 
 print(f"Discovered {len(devices)} device(s):")
 for device in devices:
-    print(f"  {device}")
+    print(
+        f"  '{device.friendly_name}' ({device.model_name}) @ {device.host}:{device.port} uuid: {device.uuid}"
+    )
+    if args.verbose:
+        print(f"  service: {device}")
