@@ -1,16 +1,22 @@
 """
 Example that shows how to connect to all chromecasts.
 """
+
 # pylint: disable=invalid-name
 
 import argparse
-import logging
 import sys
 
-import zeroconf
-
 import pychromecast
 
+from .common import add_log_arguments, configure_logging
+
+# Enable deprecation warnings etc.
+if not sys.warnoptions:
+    import warnings
+
+    warnings.simplefilter("default")
+
 parser = argparse.ArgumentParser(
     description="Example on how to connect to all chromecasts."
 )
@@ -19,17 +25,10 @@ parser.add_argument(
     help="Add known host (IP), can be used multiple times",
     action="append",
 )
-parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
-parser.add_argument(
-    "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
-)
+add_log_arguments(parser)
 args = parser.parse_args()
 
-if args.show_debug:
-    logging.basicConfig(level=logging.DEBUG)
-if args.show_zeroconf_debug:
-    print("Zeroconf version: " + zeroconf.__version__)
-    logging.getLogger("zeroconf").setLevel(logging.DEBUG)
+configure_logging(args)
 
 casts, browser = pychromecast.get_chromecasts(known_hosts=args.known_host)
 # Shut down discovery as we don't care about updates
@@ -41,5 +40,5 @@ if len(casts) == 0:
 print("Found cast devices:")
 for cast in casts:
     print(
-        f'  "{cast.name}" on mDNS/host service {cast.cast_info.services} with UUID:{cast.uuid}'  # pylint: disable=protected-access
+        f'  "{cast.name}" on mDNS/host service {cast.cast_info.services} with UUID:{cast.uuid}'
     )
