@@ -2,23 +2,28 @@
 Example on how to use queuing with Media Controller
 
 """
+
 # pylint: disable=invalid-name
 
 import argparse
-import logging
 import sys
 import time
 
-import zeroconf
-
 import pychromecast
 
+from .common import add_log_arguments, configure_logging
+
+# Enable deprecation warnings etc.
+if not sys.warnoptions:
+    import warnings
+
+    warnings.simplefilter("default")
+
 # Change to the friendly name of your Chromecast
 CAST_NAME = "Living Room"
 
 # Change to an audio or video url
 MEDIA_URLS = [
-    "https://a.files.bbci.co.uk/media/live/manifesto/audio/simulcast/dash/nonuk/dash_low/llnws/bbc_radio_fourfm.mpd",
     "https://www.bensound.com/bensound-music/bensound-jazzyfrenchy.mp3",
     "https://audio.guim.co.uk/2020/08/14-65292-200817TIFXR.mp3",
 ]
@@ -35,17 +40,10 @@ parser.add_argument(
     help="Add known host (IP), can be used multiple times",
     action="append",
 )
-parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
-parser.add_argument(
-    "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
-)
+add_log_arguments(parser)
 args = parser.parse_args()
 
-if args.show_debug:
-    logging.basicConfig(level=logging.DEBUG)
-if args.show_zeroconf_debug:
-    print("Zeroconf version: " + zeroconf.__version__)
-    logging.getLogger("zeroconf").setLevel(logging.DEBUG)
+configure_logging(args)
 
 chromecasts, browser = pychromecast.get_listed_chromecasts(
     friendly_names=[args.cast], known_hosts=args.known_host
