@@ -2,16 +2,24 @@
 Example on how to use the YouTube Controller
 
 """
+
 # pylint: disable=invalid-name
 
 import argparse
-import logging
 import sys
-import zeroconf
+from time import sleep
 
 import pychromecast
 from pychromecast.controllers.youtube import YouTubeController
 
+from .common import add_log_arguments, configure_logging
+
+
+# Enable deprecation warnings etc.
+if not sys.warnoptions:
+    import warnings
+
+    warnings.simplefilter("default")
 
 # Change to the name of your Chromecast
 CAST_NAME = "Living Room TV"
@@ -32,20 +40,13 @@ parser.add_argument(
     help="Add known host (IP), can be used multiple times",
     action="append",
 )
-parser.add_argument("--show-debug", help="Enable debug log", action="store_true")
-parser.add_argument(
-    "--show-zeroconf-debug", help="Enable zeroconf debug log", action="store_true"
-)
+add_log_arguments(parser)
 parser.add_argument(
     "--videoid", help='Youtube video ID (default: "%(default)s")', default=VIDEO_ID
 )
 args = parser.parse_args()
 
-if args.show_debug:
-    logging.basicConfig(level=logging.DEBUG)
-if args.show_zeroconf_debug:
-    print("Zeroconf version: " + zeroconf.__version__)
-    logging.getLogger("zeroconf").setLevel(logging.DEBUG)
+configure_logging(args)
 
 chromecasts, browser = pychromecast.get_listed_chromecasts(
     friendly_names=[args.cast], known_hosts=args.known_host
@@ -62,5 +63,9 @@ yt = YouTubeController()
 cast.register_handler(yt)
 yt.play_video(VIDEO_ID)
 
+# If debugging, sleep after running so we can see any error messages.
+if args.show_debug:
+    sleep(10)
+
 # Shut down discovery
 browser.stop_discovery()
